@@ -34,17 +34,12 @@
     limitations under the License.
 """
 
-from __future__ import division
-
-from builtins import str
-from past.builtins import unicode
-
 import datetime
 import logging
 import os
 import xml.dom.minidom
 import xml.parsers.expat
-from fs import open_fs
+from fs import open_fs, path
 
 from mslib.msui.mss_qt import QtGui, QtCore, QtWidgets, variant_to_string, variant_to_float
 from mslib import utils, __version__
@@ -72,8 +67,8 @@ def seconds_to_string(seconds):
 
 TABLE_FULL = [
     ("Location                   ", lambda waypoint: waypoint.location, True),
-    ("Lat\n(+-90)", lambda waypoint: waypoint.lat, True),
-    ("Lon\n(+-180)", lambda waypoint: waypoint.lon, True),
+    ("Lat\n(+-90)", lambda waypoint: round(float(waypoint.lat), 2), True),
+    ("Lon\n(+-180)", lambda waypoint: round(float(waypoint.lon), 2), True),
     ("Flightlevel", lambda waypoint: waypoint.flightlevel, True),
     ("Pressure\n(hPa)", lambda waypoint: QtCore.QLocale().toString(waypoint.pressure / 100., 'f', 2), True),
     ("Leg dist.\n(km [nm])", lambda waypoint: "{:d} [{:d}]".format(
@@ -85,10 +80,12 @@ TABLE_FULL = [
     ("Time (UTC)", lambda waypoint: waypoint.utc_time.strftime("%Y-%m-%d %H:%M:%S"), False),
     ("Rem. fuel\n(lb)", lambda waypoint: ("{:d}".format(int(waypoint.rem_fuel))), False),
     ("Aircraft\nweight (lb)", lambda waypoint: ("{:d}".format(int(waypoint.weight))), False),
+    ("Ceiling\naltitude (hft)", lambda waypoint: ("{:d}".format(waypoint.ceiling_alt)), False),
+    ("Ascent rate\n(ft/minute)", lambda waypoint: ("{:d}".format(waypoint.ascent_rate)), False),
     ("Comments                        ", lambda waypoint: waypoint.comments, True),
 ]
 
-TABLE_SHORT = [TABLE_FULL[_i] for _i in range(7)] + [TABLE_FULL[-1]] + [("", lambda _: "", False)] * 6
+TABLE_SHORT = [TABLE_FULL[_i] for _i in range(7)] + [TABLE_FULL[-1]] + [("", lambda _: "", False)] * 8
 
 
 class Waypoint(object):
@@ -118,6 +115,8 @@ class Waypoint(object):
         self.leg_fuel = None  # fuel consumption since previous waypoint
         self.rem_fuel = None  # total fuel consumption
         self.weight = None  # aircraft gross weight
+        self.ceiling_alt = None  # aircraft ceiling altitude
+        self.ascent_rate = None  # aircraft ascent rate
 
         self.wpnumber_major = None
         self.wpnumber_minor = None
@@ -142,12 +141,14 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
     flight performance calculations.
     """
 
-    def __init__(self, name="", filename=None, waypoints=None):
+    def __init__(self, name="", filename=None, waypoints=None, mscolab_mode=False):
         super(WaypointsTableModel, self).__init__()
         self.name = name  # a name for this flight track
         self.filename = filename  # filename for store/load
         self.modified = False  # for "save on exit"
         self.waypoints = []  # user-defined waypoints
+        # file-save events are handled in a different manner
+        self.mscolab_mode = mscolab_mode
 
         # self.aircraft.setErrorHandling("permissive")
         self.settings_tag = "performance"
@@ -158,7 +159,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
             if filename.endswith(".ftml"):
                 self.load_from_ftml(filename)
             else:
-                logging.debug(u"No known file extension! '%s'", filename)
+                logging.debug("No known file extension! '%s'", filename)
 
         if waypoints:
             self.replace_waypoints(waypoints)
@@ -283,10 +284,10 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 except TypeError as ex:
                     logging.error("unexpected error: %s %s %s %s", type(ex), ex, type(value), value)
                 except ValueError as ex:
-                    logging.error("{}".format(ex))
+                    logging.error("%s", ex)
                 else:
                     waypoint.lat = value
-                    waypoint.location = u""
+                    waypoint.location = ""
                     loc = find_location(waypoint.lat, waypoint.lon, 1e-3)
                     if loc is not None:
                         waypoint.lat, waypoint.lon = loc[0]
@@ -308,10 +309,10 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 except TypeError as ex:
                     logging.error("unexpected error: %s %s %s %s", type(ex), ex, type(value), value)
                 except ValueError as ex:
-                    logging.error("{}".format(ex))
+                    logging.error("%s", ex)
                 else:
                     waypoint.lon = value
-                    waypoint.location = u""
+                    waypoint.location = ""
                     loc = find_location(waypoint.lat, waypoint.lon, 1e-3)
                     if loc is not None:
                         waypoint.lat, waypoint.lon = loc[0]
@@ -328,7 +329,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 except TypeError as ex:
                     logging.error("unexpected error: %s %s %s %s", type(ex), ex, type(value), value)
                 except ValueError as ex:
-                    logging.error("{}".format(ex))
+                    logging.error("%s", ex)
                 else:
                     waypoint.flightlevel = flightlevel
                     waypoint.pressure = pressure
@@ -349,7 +350,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 except TypeError as ex:
                     logging.error("unexpected error: %s %s %s %s", type(ex), ex, type(value), value)
                 except ValueError as ex:
-                    logging.error("{}".format(ex))
+                    logging.error("%s", ex)
                 else:
                     waypoint.pressure = pressure
                     waypoint.flightlevel = flightlevel
@@ -416,9 +417,9 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
         according to the number of modified waypoints.
         """
         waypoints = self.waypoints
+        aircraft = self.performance_settings["aircraft"]
 
         def get_duration_fuel(flightlevel0, flightlevel1, distance, weight, lastleg):
-            aircraft = self.performance_settings["aircraft"]
             if flightlevel0 == flightlevel1:
                 tas, fuelflow = aircraft.get_cruise_performance(flightlevel0 * 100, weight)
                 duration = 3600. * distance / (1.852 * tas)  # convert to s (tas is in nm/h)
@@ -455,6 +456,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 wp1.weight = self.performance_settings["takeoff_weight"]
                 wp1.leg_fuel = 0
                 wp1.rem_fuel = self.performance_settings["fuel"]
+                wp1.ascent_rate = 0
             else:
                 wp0 = waypoints[pos - 1]
                 wp1.distance_to_prev = utils.get_distance((wp0.lat, wp0.lon),
@@ -469,12 +471,21 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 wp1.leg_fuel = fuel
                 wp1.rem_fuel = wp0.rem_fuel - wp1.leg_fuel
                 wp1.weight = wp0.weight - wp1.leg_fuel
+                if wp1.leg_time != 0:
+                    wp1.ascent_rate = int((wp1.flightlevel - wp0.flightlevel) * 100 / (wp1.leg_time / 60))
+                else:
+                    wp1.ascent_rate = 0
+            wp1.ceiling_alt = aircraft.get_ceiling_altitude(wp1.weight)
 
         # Update the distance of the following waypoint as well.
         if pos < len(waypoints) - 1:
             wp2 = waypoints[pos + 1]
             wp2.distance_to_prev = utils.get_distance((wp1.lat, wp1.lon),
                                                       (wp2.lat, wp2.lon))
+            if wp2.leg_time != 0:
+                wp2.ascent_rate = int((wp2.flightlevel - wp1.flightlevel) * 100 / (wp2.leg_time / 60))
+            else:
+                wp2.ascent_rate = 0
 
         # Update total distances of waypoint at index position and all
         # following waypoints.
@@ -493,6 +504,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
             wp1.leg_fuel = fuel
             wp1.rem_fuel = wp0.rem_fuel - wp1.leg_fuel
             wp1.weight = wp0.weight - wp1.leg_fuel
+            wp1.ceiling_alt = aircraft.get_ceiling_altitude(wp1.weight)
 
         index1 = self.createIndex(0, TIME_UTC)
         self.dataChanged.emit(index1, index1)
@@ -505,7 +517,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
         for i in range(1, len(self.waypoints)):
             wp_comm = self.waypoints[i].comments
             if len(wp_comm) == 9 and wp_comm.startswith("Hexagon "):
-                wp_comm = u"Hexagon {:d}".format(8 - int(wp_comm[-1]))
+                wp_comm = "Hexagon {:d}".format(8 - int(wp_comm[-1]))
                 self.waypoints[i].comments = wp_comm
         self.update_distances(position=0, rows=len(self.waypoints))
         index = self.index(0, 0)
@@ -517,6 +529,15 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
         self.waypoints = []
         self.insertRows(0, rows=len(new_waypoints), waypoints=new_waypoints)
 
+    def save_to_mscolab(self):
+        # note p_id can be a member of this class
+        logging.debug("saving to mscolab")
+        fname_temp = path.combine(mss_default.mss_dir, 'tempfile_mscolab.ftml')
+        self.save_to_ftml(filename=fname_temp)
+        _fs = open_fs(mss_default.mss_dir)
+        content = _fs.readtext('tempfile_mscolab.ftml')
+        return content
+
     def save_to_ftml(self, filename=None):
         """Save the flight track to an XML file.
 
@@ -533,28 +554,28 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
 
         doc = xml.dom.minidom.Document()
 
-        ft_el = doc.createElement(u"FlightTrack")
-        ft_el.setAttribute(u"version", unicode(__version__))
+        ft_el = doc.createElement("FlightTrack")
+        ft_el.setAttribute("version", __version__)
         doc.appendChild(ft_el)
         # The list of waypoint elements.
-        wp_el = doc.createElement(u"ListOfWaypoints")
+        wp_el = doc.createElement("ListOfWaypoints")
         ft_el.appendChild(wp_el)
 
         for wp in self.waypoints:
-            element = doc.createElement(u"Waypoint")
+            element = doc.createElement("Waypoint")
             wp_el.appendChild(element)
-            element.setAttribute(u"location", unicode(wp.location))
-            element.setAttribute(u"lat", unicode(wp.lat))
-            element.setAttribute(u"lon", unicode(wp.lon))
-            element.setAttribute(u"flightlevel", unicode(wp.flightlevel))
-            comments = doc.createElement(u"Comments")
-            comments.appendChild(doc.createTextNode(unicode(wp.comments)))
+            element.setAttribute("location", str(wp.location))
+            element.setAttribute("lat", str(wp.lat))
+            element.setAttribute("lon", str(wp.lon))
+            element.setAttribute("flightlevel", str(wp.flightlevel))
+            comments = doc.createElement("Comments")
+            comments.appendChild(doc.createTextNode(str(wp.comments)))
             element.appendChild(comments)
 
         _dirname, _name = os.path.split(self.filename)
         _fs = open_fs(_dirname)
         with _fs.open(_name, 'w') as file_object:
-            doc.writexml(file_object, indent=u"  ", addindent=u"  ", newl=u"\n", encoding=u"utf-8")
+            doc.writexml(file_object, indent="  ", addindent="  ", newl="\n", encoding="utf-8")
 
     def load_from_ftml(self, filename):
         """Load a flight track from an XML file at <filename>.
