@@ -26,8 +26,6 @@
     limitations under the License.
 """
 
-from __future__ import division
-from __future__ import print_function
 
 import os
 import netCDF4 as nc
@@ -37,54 +35,60 @@ import fs
 
 _SURFACE_TEXT = """\
 surface_geopotential
-m2.s-2
+m^2.s^-2
   2.12e+03   4.74e+03
 air_pressure_at_sea_level
 Pa
   9.89e+04   5.30e+02
 total_cloud_cover
-(0.-.1)
+dimensionless
   6.32e-01   3.93e-01
 land_binary_mask
-(0.-.1)
+dimensionless
   4.20e-01   4.94e-01
 low_cloud_area_fraction
-(0.-.1)
+dimensionless
   3.67e-01   3.91e-01
 medium_cloud_area_fraction
-(0.-.1)
+dimensionless
   2.95e-01   3.77e-01
 high_cloud_area_fraction
-(0.-.1)
+dimensionless
   4.07e-01   4.41e-01
 surface_eastward_wind
-m.s-1
+m.s^-1
   0 50
 surface_northward_wind
-m.s-1
+m.s^-1
   0 50
 solar_elevation_angle
 degree
   45 20
 sea_ice_area_fraction
-(0.-.1)
+dimensionless
   0.5 0.3
 msg_brightness_temperature_108
-nW.cm.m-2.sr-1
+nW.cm.m^-2.sr^-1
   100 20
 atmosphere_boundary_layer_thickness
 m
   1000 400
 emac_column_density
-(0.-.1)
+dimensionless
  0.25 0.2
 vertically_integrated_probability_of_wcb_occurrence
-(0.-.1)
+dimensionless
  0.25 0.2"""
 
 _PROFILES_TEXT = """\
 air_pressure
 Pa
+    20           2
+    50           5
+   100          10
+   200          20
+   500          50
+  1000         100
   2000         200
   3000         300
   5000         500
@@ -105,7 +109,13 @@ Pa
   95000       10000
 ertel_potential_vorticity
 PVU
-  1.04e+02   2.25e+01
+  3.91e+04   1.13e+04
+  1.23e+04   2.76e+03
+  6.00e+03   7.97e+02
+  2.33e+03   4.57e+02
+  7.21e+02   1.49e+02
+  2.76e+02   4.95e+01
+  1.00e+02   1.70e+01
   6.14e+01   1.03e+01
   2.94e+01   4.86e-00
   1.88e+01   3.51e-00
@@ -125,6 +135,12 @@ PVU
   1.95e-01   4.09e-00
 geopotential_height
 m
+  5.95e+01   9.22e+01
+  5.27e+01   9.22e+01
+  4.73e+01   9.22e+01
+  4.20e+01   9.22e+01
+  3.55e+01   9.22e+01
+  3.08e+01   9.22e+01
   2.57e+04   9.22e+01
   2.33e+04   6.80e+01
   2.01e+04   6.96e+01
@@ -145,6 +161,12 @@ m
   5.29e+02   7.40e+01
 air_temperature
 K
+  2.39e+02   2.74e+00
+  2.51e+02   3.59e+00
+  2.54e+02   3.84e+00
+  2.45e+02   4.40e+00
+  2.32e+02   5.15e+00
+  2.23e+02   3.03e+00
   2.15e+02   3.79e+00
   2.13e+02   2.07e+00
   2.12e+02   3.10e+00
@@ -165,6 +187,12 @@ K
   2.84e+02   7.93e+00
 air_potential_temperature
 K
+  2.80e+03   4.59e+01
+  2.26e+03   2.34e+01
+  1.85e+03   2.32e+01
+  1.45e+03   1.83e+01
+  1.05e+03   2.14e+01
+  8.29e+02   1.12e+01
   657.443538145 3.79
   580.079898831 2.07
   498.951941454 3.10
@@ -184,7 +212,13 @@ K
   288.351954158 7.97
   288.192732138 7.93
 eastward_wind
-m.s-1
+m.s^-1
+  4.68e+01   1.36e+01
+  4.57e+01   1.43e+01
+  3.97e+01   1.42e+01
+  2.96e+01   1.44e+01
+  2.08e+01   1.31e+01
+  1.70e+01   8.40e+00
   5.36e+00   7.99e+00
   3.69e+00   5.80e+00
   3.83e+00   4.66e+00
@@ -204,7 +238,13 @@ m.s-1
   1.27e+00   6.65e+00
   7.67e-01   6.35e+00
 northward_wind
-m.s-1
+m.s^-1
+  7.03e-02   1.01e+01
+ -1.88e-01   9.98e+00
+  4.11e-01   8.97e+00
+  2.13e-01   6.33e+00
+  9.45e-02   5.67e+00
+  2.35e-01   5.26e+00
  -1.19e+00   5.11e+00
  -9.02e-01   4.34e+00
  -1.01e+00   4.56e+00
@@ -224,7 +264,13 @@ m.s-1
   8.61e-01   8.81e+00
   7.32e-01   8.64e+00
 specific_humidity
-kg.kg-1
+kg.kg^-1
+  4.60e-06   3.29e-08
+  4.47e-06   2.90e-08
+  4.12e-06   8.67e-08
+  3.72e-06   1.92e-07
+  3.48e-06   1.73e-07
+  3.31e-06   1.44e-07
   2.94e-06   1.20e-07
   2.86e-06   1.10e-07
   2.68e-06   5.65e-08
@@ -244,7 +290,13 @@ kg.kg-1
   5.64e-03   2.44e-03
   6.07e-03   2.55e-03
 lagrangian_tendency_of_air_pressure
-Pa.s-1
+Pa.s^-1
+ -4.38e-03   6.64e-02
+ -7.20e-03   6.82e-02
+ -5.57e-03   5.85e-02
+ -1.87e-03   4.52e-02
+ -3.46e-03   2.90e-02
+ -5.96e-04   2.37e-02
  -2.45e-04   5.71e-03
  -4.91e-04   7.48e-03
  -9.50e-04   1.13e-02
@@ -264,7 +316,13 @@ Pa.s-1
   1.57e-02   3.60e-01
   1.85e-02   3.18e-01
 divergence_of_wind
-s-1
+s^-1
+  2.66e-09   1.74e-05
+  1.00e-06   2.00e-05
+  4.04e-06   2.49e-05
+  2.20e-06   2.36e-05
+  3.60e-07   2.05e-05
+  3.64e-07   2.07e-05
   2.19e-07   1.75e-05
   2.29e-07   1.73e-05
   2.93e-07   2.00e-05
@@ -284,7 +342,13 @@ s-1
   4.93e-08   5.71e-05
   8.47e-08   5.94e-05
 mole_fraction_of_ozone_in_air
-kg.kg-1
+kg.kg^-1
+  1.45e-06   7.50e-08
+  2.95e-06   7.83e-08
+  5.04e-06   1.71e-07
+  8.78e-06   3.11e-07
+  1.15e-05   4.18e-07
+  1.22e-05   7.58e-07
   8.09e-06   1.21e-06
   5.70e-06   5.69e-07
   3.46e-06   4.69e-07
@@ -304,7 +368,13 @@ kg.kg-1
   6.12e-08   4.64e-09
   6.09e-08   4.65e-09
 mass_fraction_of_ozone_in_air
-kg.kg-1
+kg.kg^-1
+  1.45e-06   7.50e-08
+  2.95e-06   7.83e-08
+  5.04e-06   1.71e-07
+  8.78e-06   3.11e-07
+  1.15e-05   4.18e-07
+  1.22e-05   7.58e-07
   8.09e-06   1.21e-06
   5.70e-06   5.69e-07
   3.46e-06   4.69e-07
@@ -325,6 +395,12 @@ kg.kg-1
   6.09e-08   4.65e-09
 equivalent_latitude
 degree
+  4.30e+01   1.05e+01
+  4.48e+01   8.70e+00
+  4.58e+01   5.58e+00
+  4.21e+01   8.11e+00
+  4.37e+01   7.42e+00
+  4.57e+01   5.66e+00
   80.09   1.21
   50.70   5.69
   30.46   4.69
@@ -344,7 +420,13 @@ degree
   60.12   4.64
   60.09   4.65
 cloud_area_fraction_in_atmosphere_layer
-(0.-.1)
+dimensionless
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
   0.00e+00   0.00e+00
   0.00e+00   0.00e+00
   0.00e+00   0.00e+00
@@ -365,6 +447,12 @@ cloud_area_fraction_in_atmosphere_layer
   9.84e-02   2.69e-01
 atmosphere_hybrid_pressure_coordinate
 Pa
+     20.0000 0
+     50.0000 0
+    100.0000 0
+    200.0000 0
+    500.0000 0
+   1000.0000 0
    2001.3900 0
    2997.9320 0
    4997.2623 0
@@ -385,6 +473,12 @@ Pa
     843.9551 0
 atmosphere_hybrid_height_coordinate
 1
+  0.0        0
+  0.0        0
+  0.0        0
+  0.0        0
+  0.0        0
+  0.0        0
   0.0        0
   0.0        0
   0.0        0
@@ -423,8 +517,20 @@ hybrid
   15 0
   16 0
   17 0
+  18 0
+  19 0
+  20 0
+  21 0
+  22 0
+  23 0
 specific_cloud_ice_water_content
-???
+kg.kg^-1
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
   2.94e-05   1.20e-05
   2.86e-05   1.10e-05
   2.68e-05   5.65e-05
@@ -444,7 +550,13 @@ specific_cloud_ice_water_content
   5.64e-05   2.44e-05
   6.07e-05   2.55e-05
 specific_cloud_liquid_water_content
-???
+kg.kg^-1
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
+  0.00e+00   0.00e+00
   4.99e-05   3.43e-05
   1.78e-05   1.58e-05
   5.30e-05   4.71e-05
@@ -464,7 +576,13 @@ specific_cloud_liquid_water_content
   2.70e-05   6.27e-05
   2.90e-05   2.00e-05
 emac_R12
-(0.-.100)
+dimensionless
+  12 20
+  14 20
+  16 20
+  18 20
+  20 20
+  23 20
   25 20
   28 20
   31 20
@@ -484,7 +602,13 @@ emac_R12
   73 20
   76 20
 probability_of_wcb_occurrence
-(0.-.1)
+dimensionless
+  0.0000 0.3
+  0.0000 0.3
+  0.0588 0.3
+  0.1588 0.3
+  0.2588 0.3
+  0.3588 0.3
   0.4588 0.3
   0.2345 0.3
   0.5646 0.3
@@ -504,7 +628,13 @@ probability_of_wcb_occurrence
   0.3312 0.3
   0.9137 0.3
 number_of_wcb_trajectories
-???
+dimensionless
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
   9.83136620961e-06 3e-6
   8.10710322623e-06 3e-6
   5.03285054247e-06 3e-6
@@ -524,7 +654,13 @@ number_of_wcb_trajectories
   5.17596006307e-06 3e-6
   8.12412830459e-06 3e-6
 number_of_insitu_trajectories
-???
+dimensionless
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
   1.4159717441e-06 3e-6
   7.62262321518e-06 3e-6
   8.76448539884e-06 3e-6
@@ -544,7 +680,13 @@ number_of_insitu_trajectories
   6.0163792186e-06 3e-6
   3.866286373e-06 3e-6
 number_of_mix_trajectories
-???
+dimensionless
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
+  0                 3e-6
   3.06481460477e-06 3e-6
   2.22900351535e-06 3e-6
   9.55973892153e-06 3e-6
@@ -589,7 +731,7 @@ def _parse_text(text, entry_length):
     return result
 
 
-_PROFILES = _parse_text(_PROFILES_TEXT, 20)
+_PROFILES = _parse_text(_PROFILES_TEXT, 26)
 _SURFACE = _parse_text(_SURFACE_TEXT, 3)
 
 
@@ -703,12 +845,12 @@ class DataFiles(object):
     def __init__(self, data_fs=None, server_config_fs=None):
         self.data_fs = data_fs
         self.server_config_fs = server_config_fs
-        self.server_config_file = u"mss_wms_settings.py"
-        self.server_auth_config_file = u"mss_wms_auth.py"
+        self.server_config_file = "mss_wms_settings.py"
+        self.server_auth_config_file = "mss_wms_auth.py"
         # define file dimension / geographical  range
 
     def create_server_config(self, detailed_information=False):
-        simple_auth_config = u'''# -*- coding: utf-8 -*-
+        simple_auth_config = '''# -*- coding: utf-8 -*-
 """
 
     mss_wms_settings
@@ -748,7 +890,7 @@ allowed_users = [("mswms", "add_md5_digest_of_PASSWORD_here"),
 
 '''
         if detailed_information:
-            simple_server_config = u'''# -*- coding: utf-8 -*-
+            simple_server_config = '''# -*- coding: utf-8 -*-
 """
 
     mss_wms_settings
@@ -897,7 +1039,7 @@ from mslib.mswms.demodata import (data, epsg_to_mpl_basemap_table,
             fid.write(simple_server_config)
             fid.close()
         else:
-            print(u'''
+            print('''
 /!\\ existing server config: "{}" for demodata not overwritten!
             '''.format(self.server_config_file))
         if not self.server_config_fs.exists(self.server_auth_config_file):
@@ -905,7 +1047,7 @@ from mslib.mswms.demodata import (data, epsg_to_mpl_basemap_table,
             fid.write(simple_auth_config)
             fid.close()
         else:
-            print(u'''
+            print('''
 /!\\ existing server auth config: "{}" for demodata not overwritten!
                 '''.format(self.server_auth_config_file))
 
@@ -922,7 +1064,7 @@ from mslib.mswms.demodata import (data, epsg_to_mpl_basemap_table,
         # ToDo nc.Dataset needs fileobject like access
 
         filename_out = os.path.join(
-            self.data_fs.root_path, u"20121017_12_ecmwf_forecast.{}.EUR_LL015.036.{}.nc".format(label, leveltype))
+            self.data_fs.root_path, "20121017_12_ecmwf_forecast.{}.EUR_LL015.036.{}.nc".format(label, leveltype))
         ecmwf = nc.Dataset(filename_out, 'w', format='NETCDF4_CLASSIC')
 
         for dim, values in dimvals:
@@ -1046,12 +1188,12 @@ def main():
     """
     creates various test data files and also the server configuration
     """
-    root_fs = fs.open_fs(u"~/")
-    if not root_fs.exists(u"mss/testdata"):
-        root_fs.makedirs(u"mss/testdata")
+    root_fs = fs.open_fs("~/")
+    if not root_fs.exists("mss/testdata"):
+        root_fs.makedirs("mss/testdata")
 
-    examples = DataFiles(data_fs=fs.open_fs(u"~/mss/testdata"),
-                         server_config_fs=fs.open_fs(u"~/mss"))
+    examples = DataFiles(data_fs=fs.open_fs("~/mss/testdata"),
+                         server_config_fs=fs.open_fs("~/mss"))
     examples.create_server_config(detailed_information=True)
     examples.create_data()
     print("\nTo use this setup you need the mss_wms_settings.py in your python path e.g. \nexport PYTHONPATH=~/mss")
